@@ -33,8 +33,6 @@
 #include <libgda/gda-set.h>
 #include <libgda/gda-holder.h>
 
-static gboolean append_a_row (GdaDataModel *to_model, GError **error, gint nb, ...);
-
 /*
  * predefined statements' IDs
  */
@@ -51,15 +49,12 @@ static gchar *internal_sql[] = {
 };
 
 /*
- * predefined statements' GdaStatement
+ * global static values, and
+ * predefined statements' GdaStatement, all initialized in _gda_capi_provider_meta_init()
  */
 static GdaStatement **internal_stmt;
 static GdaSet        *i_set;
-
-/* 
- * global static values
- */
-static GdaSqlParser *internal_parser = NULL;
+static GdaSqlParser  *internal_parser = NULL;
 /* TO_ADD: other static values */
 
 
@@ -69,10 +64,12 @@ static GdaSqlParser *internal_parser = NULL;
 void
 _gda_capi_provider_meta_init (GdaServerProvider *provider)
 {
+	static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
 	InternalStatementItem i;
 
-        internal_parser = gda_server_provider_internal_get_parser (provider);
+	g_static_mutex_lock (&init_mutex);
 
+        internal_parser = gda_server_provider_internal_get_parser (provider);
         internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
         for (i = I_STMT_1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
                 internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
@@ -85,6 +82,8 @@ _gda_capi_provider_meta_init (GdaServerProvider *provider)
 				    "name", G_TYPE_STRING, "",
 				    "schema", G_TYPE_STRING, "",
 				    "name2", G_TYPE_STRING, "");
+
+	g_static_mutex_unlock (&init_mutex);
 }
 
 gboolean
@@ -132,8 +131,10 @@ _gda_capi_meta_udt (GdaServerProvider *prov, GdaConnection *cnc,
 	gboolean retval = TRUE;
 
 	/* set internal holder's values from the arguments */
-	gda_holder_set_value (gda_set_get_holder (i_set, "cat"), udt_catalog);
-	gda_holder_set_value (gda_set_get_holder (i_set, "schema"), udt_schema);
+	if (! gda_holder_set_value (gda_set_get_holder (i_set, "cat"), udt_catalog, error))
+		return FALSE;
+	if (! gda_holder_set_value (gda_set_get_holder (i_set, "schema"), udt_schema, error))
+		return FALSE;
 
 	TO_IMPLEMENT;
 	/* fill in @model, with something like:
@@ -226,6 +227,15 @@ _gda_capi_meta__el_types (GdaServerProvider *prov, GdaConnection *cnc,
 	return TRUE;
 }
 
+gboolean
+_gda_capi_meta_el_types (GdaServerProvider *prov, GdaConnection *cnc, 
+			 GdaMetaStore *store, GdaMetaContext *context, GError **error,
+			 const GValue *specific_name)
+{
+	TO_IMPLEMENT;
+	return TRUE;
+}
+
 gboolean
 _gda_capi_meta__collations (GdaServerProvider *prov, GdaConnection *cnc, 
 			    GdaMetaStore *store, GdaMetaContext *context, GError **error)
